using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace Assets.Scripts.Slimes
{
    class SlimeFactory
    {
        public NormalSlime generateNormalSlime(Player player)
        {
            return new NormalSlime(player);
        }

        public MageSlime generateMageSlime(Player player)
        {
            return new MageSlime(player);
        }

        public MetalSlime generateMetalSlime(Player player)
        {
            return new MetalSlime(player);
        }

        public MiniBossSlime generateMiniBossSlime(Player player)
        {
            return new MiniBossSlime(player);
        }

        public WarriorSlime generateWarriorSlime(Player player)
        {
            return new WarriorSlime(player);
        }

        public WaterSlime generateWaterSlime(Player player)
        {
            return new WaterSlime(player);
        }

        public BossSlime generateBossSlime(Player player)
        {
            return new BossSlime(player);
        }
    }
}
